package de.tudarmstadt.informatik.hostage.ui.fragment;

import android.app.FragmentManager;
import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.TextView;
import de.tudarmstadt.informatik.hostage.R;
import de.tudarmstadt.informatik.hostage.commons.HelperUtils;
import de.tudarmstadt.informatik.hostage.system.Device;

/**
 * @author Alexander Brakowski
 * @created 24.02.14 23:37
 */
public class SettingsFragment extends UpNavigatibleFragment {
	private TextView mPorthackText;

	public View onCreateView(LayoutInflater inflater, ViewGroup container, Bundle savedInstanceState) {
		super.onCreateView(inflater, container, savedInstanceState);
		getActivity().setTitle(getResources().getString(R.string.drawer_settings));
		View v = inflater.inflate(R.layout.fragment_settings, container, false);

		TextView rootedText = (TextView) v.findViewById(R.id.settings_device_rooted);
		mPorthackText = (TextView) v.findViewById(R.id.settings_porthack_installed);
		Button porthackButton = (Button) v.findViewById(R.id.settings_deploy_porthack);

		if (Device.isRooted()) {
			rootedText.setText(R.string.yes);
			rootedText.setTextColor(getResources().getColor(R.color.holo_dark_green));
		} else {
			rootedText.setText(R.string.no);
			rootedText.setTextColor(getResources().getColor(R.color.holo_red));
		}

		updatePorthackStatus();

		porthackButton.setOnClickListener(new View.OnClickListener() {
			@Override
			public void onClick(View v) {
				HelperUtils.deployPorthack();
				updatePorthackStatus();
			}
		});
		porthackButton.setEnabled(Device.isRooted()); // we're only able to deploy if the device is rooted

		return v;
	}

	private void updatePorthackStatus() {
		Device.updatePorthack(); // get current situation

		if (Device.isPorthackInstalled()) {
			mPorthackText.setText(R.string.yes);
			mPorthackText.setTextColor(getResources().getColor(R.color.holo_dark_green));
		} else {
			mPorthackText.setText(R.string.no);
			mPorthackText.setTextColor(getResources().getColor(R.color.holo_red));
		}
	}

	public void onViewCreated(View view, Bundle savedInstanceState) {
		super.onViewCreated(view, savedInstanceState);

		FragmentManager manager = this.getFragmentManager();
		manager.beginTransaction().replace(R.id.settings_fragment_container, new PreferenceHostageFrament()).commit();
	}
}
